@@ -1,6 +1,4 @@
-use subbeat::{
-    datasources::resolve,
-};
+use subbeat::datasources::resolve;
 
 mod cli;
 mod types;
@@ -9,7 +7,7 @@ mod types;
 async fn main() -> types::Result<()> {
     let cli = cli::CLI::new();
 
-    let ds = resolve(&cli.query_config);
+    let ds = resolve(&cli.query_config.datasource_config);
 
     let r = ds
         .query(
